@@ -21,10 +21,14 @@ class NotebookRun:
     def __init__(
         self,
         filename: Path,
+        default_timeout: int,
         verbose: bool = False,
+        kernel: Optional[str] = None,
     ) -> None:
         self.filename = filename
         self.verbose = verbose
+        self.default_timeout = default_timeout
+        self.kernel = kernel
 
     def execute(
         self,
@@ -34,7 +38,7 @@ class NotebookRun:
         for cell in nb.cells:
             if cell.cell_type == "code":
                 cell.outputs = []
-        timeout = 300
+        timeout = self.default_timeout
         allow_errors = False
         if "execution" in nb.metadata:
             if "timeout" in nb.metadata.execution:
@@ -44,12 +48,17 @@ class NotebookRun:
 
         error: Optional[NotebookError] = None
 
+        extra_kwargs = {}
+        if self.kernel:
+            extra_kwargs["kernel_name"] = self.kernel
+
         try:
             c = NotebookClient(
                 nb,
                 timeout=timeout,
                 allow_errors=allow_errors,
                 record_timing=True,
+                **extra_kwargs,
             )
             c.execute(cwd=self.filename.parent)
         except CellExecutionError:
