@@ -26,6 +26,19 @@ def pytest_addoption(parser: Any):
         help="Overwrite the source ipynbs",
         default=False,
     )
+    group.addoption(
+        "--nbmake-timeout",
+        action="store",
+        help="Sets the default cell timeout (seconds)",
+        default=300,
+        type=int,
+    )
+    group.addoption(
+        "--nbmake-kernel",
+        action="store",
+        help="Overrides the kernel used for all notebooks",
+        type=str,
+    )
 
 
 def pytest_collect_file(path: str, parent: Any) -> Optional[Any]:
